<?php
// Prevent direct access
if (!defined('ABSPATH')) {
    exit;
}

function khattam_settings_page() {
    $active_tab = isset($_GET['tab']) ? sanitize_key($_GET['tab']) : 'main';
    ?>
    <div class="wrap">
        <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
        
        <h2 class="nav-tab-wrapper">
            <a href="?page=khattam&tab=main" class="nav-tab <?php echo $active_tab === 'main' ? 'nav-tab-active' : ''; ?>">
                <?php esc_html_e('Main Settings', 'khattam'); ?>
            </a>
            <a href="?page=khattam&tab=cleanup" class="nav-tab <?php echo $active_tab === 'cleanup' ? 'nav-tab-active' : ''; ?>">
                <?php esc_html_e('Cleanup Tools', 'khattam'); ?>
            </a>
        </h2>

        <div class="khattam-admin-container">
            <form action="options.php" method="post" class="khattam-form">
                <?php
                if ($active_tab === 'main') {
                    settings_fields('khattam_options');
                    do_settings_sections('khattam_main');
                    submit_button(esc_html__('Save Settings', 'khattam'));
                } else {
                    settings_fields('khattam_options');
                    do_settings_sections('khattam_cleanup');
                }
                ?>
            </form>
            <?php if ($active_tab === 'main') : ?>
            <div class="khattam-sidebar">
                <div class="khattam-widget">
                    <h3><?php esc_html_e('Plugin Information', 'khattam'); ?></h3>
                    <p><?php esc_html_e('Version:', 'khattam'); ?> 1.1</p>
                    <p><?php esc_html_e('Developer:', 'khattam'); ?> <a href="https://mostaql.com/u/Ali__Malas" target="_blank"><?php esc_html_e('Ali Malas', 'khattam'); ?></a></p>
                </div>
                <div class="khattam-widget">
                    <h3><?php esc_html_e('Support', 'khattam'); ?></h3>
                    <p><?php esc_html_e('If you need help or want to request custom features, you can', 'khattam'); ?> 
                       <a href="https://mostaql.com/u/Ali__Malas" target="_blank"><?php esc_html_e('contact the developer on Mostaql', 'khattam'); ?></a>.</p>
                </div>
            </div>
            <?php endif; ?>
        </div>
    </div>
    <?php
}

function khattam_settings_init() {
    register_setting(
        'khattam_options',
        'khattam_logo',
        array(
            'type' => 'string',
            'sanitize_callback' => 'khattam_sanitize_logo',
            'default' => ''
        )
    );

    register_setting(
        'khattam_options',
        'khattam_logo_position',
        array(
            'type' => 'string',
            'sanitize_callback' => 'khattam_sanitize_logo_position',
            'default' => 'bottom-right'
        )
    );

    register_setting(
        'khattam_options',
        'khattam_logo_size',
        array(
            'type' => 'integer',
            'sanitize_callback' => 'khattam_sanitize_logo_size',
            'default' => 10
        )
    );

    register_setting(
        'khattam_options',
        'khattam_logo_opacity',
        array(
            'type' => 'integer',
            'sanitize_callback' => 'khattam_sanitize_logo_opacity',
            'default' => 100
        )
    );

    register_setting(
        'khattam_options',
        'khattam_enabled',
        array(
            'type' => 'boolean',
            'sanitize_callback' => 'khattam_sanitize_checkbox',
            'default' => true
        )
    );

    register_setting(
        'khattam_options',
        'khattam_show_media_buttons',
        array(
            'type' => 'boolean',
            'sanitize_callback' => 'khattam_sanitize_checkbox',
            'default' => true
        )
    );

    register_setting(
        'khattam_options',
        'khattam_cleanup_batch_size',
        array(
            'type' => 'integer',
            'sanitize_callback' => 'absint',
            'default' => 50
        )
    );

    // Main settings tab
    add_settings_section(
        'khattam_section_main',
        esc_html__('Main Settings', 'khattam'),
        'khattam_section_main_callback',
        'khattam_main'
    );

    add_settings_field(
        'khattam_field_enabled',
        esc_html__('Enable Watermark', 'khattam'),
        'khattam_field_enabled_callback',
        'khattam_main',
        'khattam_section_main'
    );

    add_settings_field(
        'khattam_field_logo',
        esc_html__('Choose Logo', 'khattam'),
        'khattam_field_logo_callback',
        'khattam_main',
        'khattam_section_main'
    );

    add_settings_field(
        'khattam_field_logo_position',
        esc_html__('Logo Position', 'khattam'),
        'khattam_field_logo_position_callback',
        'khattam_main',
        'khattam_section_main'
    );

    add_settings_field(
        'khattam_field_logo_size',
        esc_html__('Logo Size', 'khattam'),
        'khattam_field_logo_size_callback',
        'khattam_main',
        'khattam_section_main'
    );

    add_settings_field(
        'khattam_field_logo_opacity',
        esc_html__('Logo Opacity', 'khattam'),
        'khattam_field_logo_opacity_callback',
        'khattam_main',
        'khattam_section_main'
    );

    add_settings_field(
        'khattam_field_show_media_buttons',
        esc_html__('Show Media Library Buttons', 'khattam'),
        'khattam_field_show_media_buttons_callback',
        'khattam_main',
        'khattam_section_main'
    );

    // Cleanup tools tab
    add_settings_section(
        'khattam_section_cleanup',
        esc_html__('Cleanup Tools', 'khattam'),
        'khattam_section_cleanup_callback',
        'khattam_cleanup'
    );

    add_settings_field(
        'khattam_field_cleanup',
        esc_html__('Original Images Cleanup', 'khattam'),
        'khattam_field_cleanup_callback',
        'khattam_cleanup',
        'khattam_section_cleanup'
    );

    add_settings_field(
        'khattam_field_batch_size',
        esc_html__('Batch Size', 'khattam'),
        'khattam_field_batch_size_callback',
        'khattam_cleanup',
        'khattam_section_cleanup'
    );
}
add_action('admin_init', 'khattam_settings_init');

function khattam_section_main_callback($args) {
    ?>
    <p><?php esc_html_e('Configure your watermark settings here.', 'khattam'); ?></p>
    <?php
}

function khattam_field_enabled_callback($args) {
    $enabled = get_option('khattam_enabled', '1');
    ?>
    <label class="switch">
        <input type="checkbox" name="khattam_enabled" value="1" <?php checked('1', $enabled); ?>>
        <span class="slider round"></span>
    </label>
    <p class="description"><?php esc_html_e('Enable or disable automatic watermarking for new images.', 'khattam'); ?></p>
    <?php
}

function khattam_field_logo_callback($args) {
    $logo = get_option('khattam_logo');
    ?>
    <input type="text" name="khattam_logo" value="<?php echo esc_attr($logo); ?>" class="regular-text" id="khattam_logo_input">
    <input type="button" class="button button-secondary" value="<?php esc_attr_e('Choose Logo', 'khattam'); ?>" id="khattam_logo_button">
    <p class="description"><?php esc_html_e('Select the logo image to be used as a watermark.', 'khattam'); ?></p>
    <?php if ($logo): ?>
        <img src="<?php echo esc_url($logo); ?>" alt="<?php esc_attr_e('Logo Preview', 'khattam'); ?>" class="khattam-logo-preview">
    <?php endif; ?>
    <?php
}

function khattam_field_logo_position_callback($args) {
    $position = get_option('khattam_logo_position', 'bottom-right');
    ?>
    <select name="khattam_logo_position">
        <option value="top-left" <?php selected($position, 'top-left'); ?>><?php esc_html_e('Top Left', 'khattam'); ?></option>
        <option value="top-right" <?php selected($position, 'top-right'); ?>><?php esc_html_e('Top Right', 'khattam'); ?></option>
        <option value="bottom-left" <?php selected($position, 'bottom-left'); ?>><?php esc_html_e('Bottom Left', 'khattam'); ?></option>
        <option value="bottom-right" <?php selected($position, 'bottom-right'); ?>><?php esc_html_e('Bottom Right', 'khattam'); ?></option>
    </select>
    <p class="description"><?php esc_html_e('Select the position of the logo on the image.', 'khattam'); ?></p>
    <?php
}

function khattam_field_logo_size_callback($args) {
    $size = get_option('khattam_logo_size', '10');
    ?>
    <input type="range" name="khattam_logo_size" min="1" max="100" value="<?php echo esc_attr($size); ?>" class="khattam-range">
    <span class="khattam-range-value"><?php echo esc_html($size); ?>%</span>
    <p class="description"><?php esc_html_e('Set the logo size as a percentage of the image size.', 'khattam'); ?></p>
    <?php
}

function khattam_field_logo_opacity_callback($args) {
    $opacity = get_option('khattam_logo_opacity', '100');
    ?>
    <input type="range" name="khattam_logo_opacity" min="0" max="100" value="<?php echo esc_attr($opacity); ?>" class="khattam-range">
    <span class="khattam-range-value"><?php echo esc_html($opacity); ?>%</span>
    <p class="description"><?php esc_html_e('Set the logo opacity (100% means fully opaque).', 'khattam'); ?></p>
    <?php
}

function khattam_field_show_media_buttons_callback($args) {
    $show_buttons = get_option('khattam_show_media_buttons', '1');
    ?>
    <label class="switch">
        <input type="checkbox" name="khattam_show_media_buttons" value="1" <?php checked('1', $show_buttons); ?>>
        <span class="slider round"></span>
    </label>
    <p class="description"><?php esc_html_e('Show watermark buttons in media library for each image.', 'khattam'); ?></p>
    <?php
}

function khattam_section_cleanup_callback() {
    echo '<p>' . esc_html__('Tools for managing original images storage.', 'khattam') . '</p>';
}

function khattam_field_cleanup_callback() {
    ?>
    <button type="button" id="khattam-start-cleanup" class="button button-danger">
        <?php esc_html_e('Delete All Originals', 'khattam'); ?>
    </button>
    <p class="description">
        <?php esc_html_e('Permanently delete all stored original image files. This action cannot be undone!', 'khattam'); ?>
    </p>
    <?php
}

function khattam_field_batch_size_callback() {
    $batch_size = get_option('khattam_cleanup_batch_size', 50);
    ?>
    <input type="number" name="khattam_cleanup_batch_size" 
           value="<?php echo esc_attr($batch_size); ?>" min="1" max="500">
    <p class="description">
        <?php esc_html_e('Number of images to process per batch (recommended 50-100 for better performance)', 'khattam'); ?>
    </p>
    <?php
}

function khattam_add_menu() {
    add_options_page(
        esc_html__('Khattam Settings', 'khattam'),
        esc_html__('Khattam', 'khattam'),
        'manage_options',
        'khattam',
        'khattam_settings_page'
    );
}
add_action('admin_menu', 'khattam_add_menu');

// Sanitize logo path
function khattam_sanitize_logo($input) {
    // Verify that the path is a valid URL
    $input = esc_url_raw($input);
    
    // Verify that the file is an image
    $filetype = wp_check_filetype($input);
    $allowed_types = array('jpg', 'jpeg', 'png', 'gif');
    
    if (!in_array($filetype['ext'], $allowed_types)) {
        add_settings_error(
            'khattam_logo',
            'invalid_logo_type',
            esc_html__('Logo must be a valid image file (JPG, PNG, or GIF)', 'khattam')
        );
        return get_option('khattam_logo');
    }
    
    return $input;
}

// Sanitize logo position
function khattam_sanitize_logo_position($input) {
    $valid_positions = array('top-left', 'top-right', 'bottom-left', 'bottom-right');
    
    if (!in_array($input, $valid_positions)) {
        add_settings_error(
            'khattam_logo_position',
            'invalid_position',
            esc_html__('Invalid logo position selected', 'khattam')
        );
        return get_option('khattam_logo_position', 'bottom-right');
    }
    
    return $input;
}

// Sanitize logo size
function khattam_sanitize_logo_size($input) {
    $input = absint($input);
    
    if ($input < 1 || $input > 100) {
        add_settings_error(
            'khattam_logo_size',
            'invalid_size',
            esc_html__('Logo size must be between 1 and 100', 'khattam')
        );
        return get_option('khattam_logo_size', 10);
    }
    
    return $input;
}

// Sanitize logo opacity
function khattam_sanitize_logo_opacity($input) {
    $input = absint($input);
    
    if ($input < 0 || $input > 100) {
        add_settings_error(
            'khattam_logo_opacity',
            'invalid_opacity',
            esc_html__('Logo opacity must be between 0 and 100', 'khattam')
        );
        return get_option('khattam_logo_opacity', 100);
    }
    
    return $input;
}

// Sanitize checkbox values
function khattam_sanitize_checkbox($input) {
    return (bool) $input;
}

function khattam_sanitize_cleanup_batch_size($input) {
    $input = absint($input);
    return $input >= 1 && $input <= 500 ? $input : 50;
}