jQuery(document).ready(function($) {
    var frame;
    $('input[name="khattam_logo"]').on('click', function(e) {
        e.preventDefault();
        if (frame) {
            frame.open();
            return;
        }
        frame = wp.media({
            title: khattamVars.i18n.chooseOrUploadLogo,
            button: {
                text: khattamVars.i18n.useThisLogo
            },
            multiple: false
        });
        frame.on('select', function() {
            var attachment = frame.state().get('selection').first().toJSON();
            $('input[name="khattam_logo"]').val(attachment.url);
        });
        frame.open();
    });

    // Add event handler for watermark application button
    $(document).on('click', '.khattam-apply-watermark', function() {
        var imageId = $(this).data('id');
        var position = $('#attachments-' + imageId + '-khattam_logo_position').val();
        var size = $('#attachments-' + imageId + '-khattam_logo_size').val();
        var opacity = $('#attachments-' + imageId + '-khattam_logo_opacity').val();
        
        if (confirm(khattamVars.i18n.confirmAddLogo)) {
            var $button = $(this);
            $button.prop('disabled', true).text(khattamVars.i18n.applying);
            
            $.ajax({
                url: ajaxurl,
                type: 'POST',
                data: {
                    action: 'khattam_apply_watermark',
                    image_id: imageId,
                    position: position,
                    size: size,
                    opacity: opacity,
                    nonce: khattamVars.nonce
                },
                success: function(response) {
                    if (response.success) {
                        alert(khattamVars.i18n.logoAddedSuccess);
                        var $img = $button.closest('.attachment-details').find('.thumbnail img');
                        var newSrc = response.data.url + '?t=' + new Date().getTime();
                        $img.attr('src', newSrc);
                        $('.attachment[data-id="' + imageId + '"] .thumbnail img').attr('src', newSrc);
                    } else {
                        alert(khattamVars.i18n.errorAddingLogo);
                    }
                    $button.prop('disabled', false).text(khattamVars.i18n.applyWatermark);
                }
            });
        }
    });

    // Modify event handler for watermark removal button
    $(document).on('click', '.khattam-remove-watermark', function() {
        var imageId = $(this).data('id');
        
        if (confirm(khattamVars.i18n.confirmRemove)) {
            var $button = $(this);
            $button.prop('disabled', true).text(khattamVars.i18n.removing);
            
            $.ajax({
                url: ajaxurl,
                type: 'POST',
                data: {
                    action: 'khattam_remove_watermark',
                    image_id: imageId,
                    nonce: khattamVars.nonce
                },
                success: function(response) {
                    console.log('Khattam: AJAX Response', response);
                    if (response.success) {
                        alert(khattamVars.i18n.logoRemovedSuccess);
                        var $img = $button.closest('.attachment-details').find('.thumbnail img');
                        var newSrc = response.data.url + '?t=' + new Date().getTime();
                        $img.attr('src', newSrc);
                        $('.attachment[data-id="' + imageId + '"] .thumbnail img').attr('src', newSrc);
                        $('img[data-id="' + imageId + '"]').attr('src', newSrc);
                        $('.wp-list-table .attachment-' + imageId + ' .media-icon img').attr('src', newSrc);
                    } else {
                        alert(khattamVars.i18n.errorRemovingLogo + ': ' + (response.data || khattamVars.i18n.unknownError));
                    }
                },
                error: function(jqXHR, textStatus, errorThrown) {
                    console.error('Khattam: AJAX Error', textStatus, errorThrown);
                    alert(khattamVars.i18n.serverError + ': ' + textStatus);
                },
                complete: function() {
                    $button.prop('disabled', false).text(khattamVars.i18n.removeWatermark);
                }
            });
        }
    });

    // Add code to update images in classic editor
    if (typeof wp !== 'undefined' && wp.media && wp.media.editor) {
        wp.media.editor.open = (function(originalFunction) {
            return function() {
                var result = originalFunction.apply(this, arguments);
                wp.media.frame.on('select', function() {
                    var attachment = wp.media.frame.state().get('selection').first().toJSON();
                    $('img[data-id="' + attachment.id + '"]').attr('src', attachment.url + '?t=' + new Date().getTime());
                });
                return result;
            };
        })(wp.media.editor.open);
    }

    // Add code to update images in Gutenberg editor
    if (wp.data && wp.data.subscribe) {
        wp.data.subscribe(function () {
            var blocks = wp.data.select('core/block-editor').getBlocks();
            blocks.forEach(function(block) {
                if (block.name === 'core/image' && block.attributes.id) {
                    var $img = $('img[data-id="' + block.attributes.id + '"]');
                    if ($img.length) {
                        var currentSrc = $img.attr('src');
                        $img.attr('src', currentSrc + '?t=' + new Date().getTime());
                    }
                }
            });
        });
    }

    // Update images after bulk actions
    function updateImagesAfterBulkAction() {
        $('.wp-list-table .attachment').each(function() {
            var $attachment = $(this);
            var imageId = $attachment.data('id');
            var $img = $attachment.find('.thumbnail img');
            var currentSrc = $img.attr('src');
            $img.attr('src', currentSrc + '?t=' + new Date().getTime());
        });
    }

    // Listen for list update event after bulk actions
    $(document).on('DOMNodeInserted', function(e) {
        var $element = $(e.target);
        if ($element.hasClass('updated') && $element.text().indexOf('Processed') !== -1) {
            updateImagesAfterBulkAction();
        }
    });
});
