(function(wp) {
    var el = wp.element.createElement;
    var __ = wp.i18n.__;
    var registerPlugin = wp.plugins.registerPlugin;
    var PluginDocumentSettingPanel = wp.editPost.PluginDocumentSettingPanel;
    var Button = wp.components.Button;
    var useSelect = wp.data.useSelect;
    var useDispatch = wp.data.useDispatch;
    var SelectControl = wp.components.SelectControl;
    var RangeControl = wp.components.RangeControl;

    function LogoImageOverlay() {
        // Initialize state variables
        var [isApplying, setIsApplying] = wp.element.useState(false);
        var [isRemoving, setIsRemoving] = wp.element.useState(false);
        var [logoPosition, setLogoPosition] = wp.element.useState(khattamVars.logoPosition);
        var [logoSize, setLogoSize] = wp.element.useState(khattamVars.logoSize);
        var [logoOpacity, setLogoOpacity] = wp.element.useState(khattamVars.logoOpacity);

        // Get all images in the current post
        var postImages = useSelect(function(select) {
            var blocks = select('core/block-editor').getBlocks();
            return blocks.filter(function(block) {
                return block.name === 'core/image';
            }).map(function(block) {
                return block.attributes.id;
            });
        }, []);

        var { editPost } = useDispatch('core/editor');

        // Function to update image URL in editor
        function updateImageInEditor(imageId, newUrl) {
            var blocks = wp.data.select('core/block-editor').getBlocks();
            blocks.forEach(function(block) {
                if (block.name === 'core/image' && block.attributes.id === imageId) {
                    wp.data.dispatch('core/block-editor').updateBlockAttributes(block.clientId, {
                        url: newUrl + '?t=' + new Date().getTime()
                    });
                }
            });
        }

        // Function to apply logo to all images
        function applyLogoToAllImages() {
            if (postImages.length === 0) {
                alert(khattamVars.i18n.noImagesFound);
                return;
            }

            setIsApplying(true);

            var processedImages = 0;
            postImages.forEach(function(imageId) {
                wp.ajax.post('khattam_apply_watermark', {
                    action: 'khattam_apply_watermark',
                    image_id: imageId,
                    nonce: khattamVars.nonce,
                    position: logoPosition,
                    size: logoSize,
                    opacity: logoOpacity
                }).then(function(response) {
                    processedImages++;
                    updateImageInEditor(imageId, response.url);
                    if (processedImages === postImages.length) {
                        setIsApplying(false);
                        alert(khattamVars.i18n.logoAppliedToAllImages);
                    }
                }).fail(function(response) {
                    console.error(khattamVars.i18n.errorApplyingLogo, response);
                    processedImages++;
                    if (processedImages === postImages.length) {
                        setIsApplying(false);
                        alert(khattamVars.i18n.errorApplyingSomeLogos);
                    }
                });
            });
        }

        // Function to remove logo from all images
        function removeLogoFromAllImages() {
            if (postImages.length === 0) {
                alert(khattamVars.i18n.noImagesFound);
                return;
            }

            setIsRemoving(true);

            var processedImages = 0;
            postImages.forEach(function(imageId) {
                wp.ajax.post('khattam_remove_watermark', {
                    action: 'khattam_remove_watermark',
                    image_id: imageId,
                    nonce: khattamVars.nonce
                }).then(function(response) {
                    processedImages++;
                    updateImageInEditor(imageId, response.url);
                    if (processedImages === postImages.length) {
                        setIsRemoving(false);
                        alert(khattamVars.i18n.logoRemovedFromAllImages);
                    }
                }).fail(function(response) {
                    console.error(khattamVars.i18n.errorRemovingLogo, response);
                    processedImages++;
                    if (processedImages === postImages.length) {
                        setIsRemoving(false);
                        alert(khattamVars.i18n.errorRemovingSomeLogos);
                    }
                });
            });
        }

        // Render the plugin panel
        return el(
            PluginDocumentSettingPanel,
            {
                name: 'logo-image-overlay-panel',
                title: khattamVars.i18n.manageLogo,
                icon: 'format-image'
            },
            el(SelectControl, {
                label: khattamVars.i18n.logoPosition,
                value: logoPosition,
                options: [
                    { label: khattamVars.i18n.topLeft, value: 'top-left' },
                    { label: khattamVars.i18n.topRight, value: 'top-right' },
                    { label: khattamVars.i18n.bottomLeft, value: 'bottom-left' },
                    { label: khattamVars.i18n.bottomRight, value: 'bottom-right' }
                ],
                onChange: setLogoPosition
            }),
            el(RangeControl, {
                label: khattamVars.i18n.logoSizePercent,
                value: logoSize,
                onChange: setLogoSize,
                min: 1,
                max: 100
            }),
            el(RangeControl, {
                label: khattamVars.i18n.logoOpacityPercent,
                value: logoOpacity,
                onChange: setLogoOpacity,
                min: 0,
                max: 100
            }),
            el(Button, {
                isPrimary: true,
                onClick: applyLogoToAllImages,
                disabled: isApplying || isRemoving,
                isBusy: isApplying
            }, isApplying ? khattamVars.i18n.applyingLogo : khattamVars.i18n.applyLogoToAllImages),
            el(Button, {
                isSecondary: true,
                onClick: removeLogoFromAllImages,
                disabled: isApplying || isRemoving,
                isBusy: isRemoving,
                style: { marginTop: '10px' }
            }, isRemoving ? khattamVars.i18n.removingLogo : khattamVars.i18n.removeLogoFromAllImages),
            el('p', { style: { marginTop: '10px' } },
                khattamVars.i18n.numberOfImages + ': ' + postImages.length
            )
        );
    }

    // Register the plugin when DOM is ready
    wp.domReady(function() {
        registerPlugin('logo-image-overlay', {
            render: LogoImageOverlay,
            icon: 'format-image'
        });
    });
})(window.wp);
