jQuery(document).ready(function($) {
    $('#khattam_logo_button').click(function(e) {
        e.preventDefault();
        var image = wp.media({
            title: khattamVars.chooseLogoImageTitle,
            multiple: false
        }).open()
        .on('select', function(e){
            var uploaded_image = image.state().get('selection').first();
            var image_url = uploaded_image.toJSON().url;
            $('#khattam_logo_input').val(image_url);
            $('.khattam-logo-preview').attr('src', image_url).show();
        });
    });

    $('.khattam-range').on('input', function() {
        $(this).next('.khattam-range-value').text($(this).val() + '%');
    });

    $('#khattam-start-cleanup').click(function(e) {
        e.preventDefault();
        
        if (!confirm(khattamVars.i18n.confirmCleanup)) {
            return;
        }
        
        var $button = $(this);
        var batchSize = $('input[name="khattam_cleanup_batch_size"]').val();
        
        var progressModal = $(`
            <div class="khattam-cleanup-modal" style="position:fixed; top:50%; left:50%; transform:translate(-50%,-50%); background:#fff; padding:20px; box-shadow:0 0 20px rgba(0,0,0,0.2); z-index:99999;">
                <h3>${khattamVars.i18n.cleanupInProgress}</h3>
                <div class="progress-container" style="width:400px; height:20px; background:#f0f0f0; margin:10px 0;">
                    <div class="progress-bar" style="height:100%; background:#0073aa; width:0%; transition:width 0.3s"></div>
                </div>
                <div class="progress-text" style="margin-bottom:15px;"></div>
                <div class="file-counter" style="margin-bottom:15px;"></div>
                <button class="button button-secondary cancel-cleanup">${khattamVars.i18n.cancel}</button>
            </div>
        `).appendTo('body');
        
        var totalProcessed = 0;
        var totalDeleted = 0;
        var isCancelled = false;
        
        function processBatch(page = 1) {
            if (isCancelled) return;
            
            $.ajax({
                url: ajaxurl,
                method: 'POST',
                data: {
                    action: 'khattam_cleanup_originals',
                    batch_size: batchSize,
                    page: page,
                    nonce: khattamVars.nonce
                },
                success: function(response) {
                    if (response.success) {
                        var percent = (response.data.processed / response.data.total * 100).toFixed(1);
                        progressModal.find('.progress-bar').css('width', percent + '%');
                        progressModal.find('.progress-text').html(`
                            ${percent}% (${response.data.processed}/${response.data.total})
                        `);
                        
                        totalDeleted += (response.data.processed - (page - 1) * batchSize);
                        progressModal.find('.file-counter').html(`
                            ${khattamVars.i18n.deletedFiles}: ${totalDeleted}
                        `);
                        
                        if (!response.data.complete) {
                            processBatch(response.data.page);
                        } else {
                            progressModal.html(`
                                <h3>${khattamVars.i18n.cleanupComplete}</h3>
                                <p>${khattamVars.i18n.totalDeleted}: ${totalDeleted}</p>
                                <button class="button button-primary close-cleanup">${khattamVars.i18n.close}</button>
                            `);
                        }
                    }
                },
                error: function() {
                    alert(khattamVars.i18n.cleanupError);
                    progressModal.remove();
                }
            });
        }
        
        progressModal.on('click', '.cancel-cleanup', function() {
            isCancelled = true;
            progressModal.remove();
        });
        
        progressModal.on('click', '.close-cleanup', function() {
            progressModal.remove();
        });
        
        processBatch(1);
    });

    // Handle tab clicks
    $('.nav-tab').on('click', function(e) {
        e.preventDefault();
        var tab = $(this).attr('href').split('tab=')[1];
        window.location.search = '?page=khattam&tab=' + tab;
    });
});